++++++++++++
facadedevice
++++++++++++

.. image:: https://readthedocs.org/projects/tango-facadedevice/badge/?version=latest
   :target: http://tango-facadedevice.readthedocs.io/
   :alt:

.. image:: https://gitlab.com/MaxIV/tango-facadedevice/badges/main/coverage.svg
   :target: https://gitlab.com/MaxIV/tango-facadedevice
   :alt:

.. image:: https://gitlab.com/MaxIV/tango-facadedevice/badges/main/pipeline.svg
   :target: https://gitlab.com/MaxIV/tango-facadedevice
   :alt:

.. image:: https://img.shields.io/pypi/v/facadedevice.svg
   :target: https://pypi.python.org/pypi/facadedevice
   :alt:

.. image:: https://img.shields.io/pypi/pyversions/facadedevice.svg
   :target: https://pypi.python.org/pypi/facadedevice
   :alt:

A descritive interface for reactive high-level Tango devices.

.. toctree::
   :maxdepth: 2

   presentation
   tutorial
   advanced
   limitations
   reference
   examples
